[llvm-commits] CVS: llvm/include/llvm/Transforms/Scalar.h

Chris Lattner lattner at cs.uiuc.edu
Sun Oct 12 16:54:06 PDT 2003


Changes in directory llvm/include/llvm/Transforms:

Scalar.h updated: 1.26 -> 1.27

---
Log message:

Rename loop preheaders pass to loop simplify


---
Diffs of the changes:  (+6 -6)

Index: llvm/include/llvm/Transforms/Scalar.h
diff -u llvm/include/llvm/Transforms/Scalar.h:1.26 llvm/include/llvm/Transforms/Scalar.h:1.27
--- llvm/include/llvm/Transforms/Scalar.h:1.26	Sun Oct  5 14:15:13 2003
+++ llvm/include/llvm/Transforms/Scalar.h	Sun Oct 12 16:52:13 2003
@@ -232,14 +232,14 @@
 
 //===----------------------------------------------------------------------===//
 //
 // LoopPreheaders pass - Insert Pre-header blocks into the CFG for every
 // function in the module.  This pass updates dominator information, loop
 // information, and does not add critical edges to the CFG.
 //
-//   AU.addRequiredID(LoopPreheadersID);
+//   AU.addRequiredID(LoopSimplifyID);
 //
-Pass *createLoopPreheaderInsertionPass();
-extern const PassInfo *LoopPreheadersID;
+Pass *createLoopSimplifyPass();
+extern const PassInfo *LoopSimplifyID;
 
 //===----------------------------------------------------------------------===//
 // 
@@ -232,14 +232,14 @@
 //===----------------------------------------------------------------------===//
 //
-// LoopPreheaders pass - Insert Pre-header blocks into the CFG for every
-// function in the module.  This pass updates dominator information, loop
-// information, and does not add critical edges to the CFG.
+// LoopSimplify pass - Insert Pre-header blocks into the CFG for every function
+// in the module.  This pass updates dominator information, loop information,
+// and does not add critical edges to the CFG.
 //





More information about the llvm-commits mailing list